@@ -1,9 +1,9 @@
 SELECT 
-  FK.PKTABLE_CAT,
+  NULLIF(1, 1) AS FK.PKTABLE_CAT,
   FK.PKTABLE_SCHEM,
   FK.PKTABLE_NAME,
   FK.PKCOLUMN_NAME,
-  FK.FKTABLE_CAT,
+  NULLIF(1, 1) AS FK.FKTABLE_CAT,
   FK.FKTABLE_SCHEM,
   FK.FKTABLE_NAME,
   FK.FKCOLUMN_NAME,
@@ -16,4 +16,8 @@ SELECT
   FK.UNIQUE_OR_PRIMARY
 FROM
   SYSIBM.SQLFOREIGNKEYS FK
+  INNER JOIN SYSCAT.TABLES T
+    ON T.TABSCHEMA = FK.FKTABLE_SCHEM AND T.TABNAME = FK.FKTABLE_NAME
+WHERE
+  T.TYPE != 'A' -- Do not include imported foreign keys for synonyms   
 WITH UR
