@@ -1,4 +1,4 @@
-SELECT /*+ PARALLEL(AUTO) */
+SELECT
   NULL AS TABLE_CAT,
   INDEXES.OWNER AS TABLE_SCHEM,
   INDEXES.TABLE_NAME,
@@ -12,32 +12,27 @@ SELECT /*+ PARALLEL(AUTO) */
   INDEXES.DISTINCT_KEYS AS CARDINALITY,
   INDEXES.LEAF_BLOCKS AS PAGES,
   NULL AS FILTER_CONDITION
-FROM 
+FROM
   ${catalogscope}_INDEXES INDEXES
   INNER JOIN ${catalogscope}_IND_COLUMNS INDEX_COLUMNS
-  ON 
+  ON
     INDEXES.INDEX_NAME = INDEX_COLUMNS.INDEX_NAME
     AND INDEXES.TABLE_OWNER = INDEX_COLUMNS.TABLE_OWNER
     AND INDEXES.TABLE_NAME = INDEX_COLUMNS.TABLE_NAME
     AND INDEXES.OWNER = INDEX_COLUMNS.INDEX_OWNER
+  INNER JOIN ${catalogscope}_USERS USERS
+    ON INDEXES.OWNER = USERS.USERNAME
+      AND USERS.ORACLE_MAINTAINED = 'N'
+      AND NOT REGEXP_LIKE(USERS.USERNAME, '^APEX_[0-9]{6}$')
+      AND NOT REGEXP_LIKE(USERS.USERNAME, '^FLOWS_[0-9]{5}$')
 WHERE
-  INDEXES.OWNER NOT IN 
-    ('ANONYMOUS', 'APEX_PUBLIC_USER', 'APPQOSSYS', 'BI', 'CTXSYS', 'DBSNMP', 'DIP', 
-    'EXFSYS', 'FLOWS_30000', 'FLOWS_FILES', 'GSMADMIN_INTERNAL', 'IX', 'LBACSYS', 
-    'MDDATA', 'MDSYS', 'MGMT_VIEW', 'OE', 'OLAPSYS', 'ORACLE_OCM', 
-    'ORDPLUGINS', 'ORDSYS', 'OUTLN', 'OWBSYS', 'PM', 'SCOTT', 'SH', 
-    'SI_INFORMTN_SCHEMA', 'SPATIAL_CSW_ADMIN_USR', 'SPATIAL_WFS_ADMIN_USR', 
-    'SYS', 'SYSMAN', 'SYSTEM', 'TSMSYS', 'WKPROXY', 'WKSYS', 'WK_TEST', 
-    'WMSYS', 'XDB', 'XS$NULL', 'RDSADMIN')  
-  AND NOT REGEXP_LIKE(INDEXES.OWNER, '^APEX_[0-9]{6}$')
-  AND NOT REGEXP_LIKE(INDEXES.OWNER, '^FLOWS_[0-9]{5,6}$')
-  AND REGEXP_LIKE(INDEXES.OWNER, '${schemas}')
+  REGEXP_LIKE(INDEXES.OWNER, '${schemas}')
   AND INDEXES.TABLE_NAME NOT LIKE 'BIN$%'
   AND NOT REGEXP_LIKE(INDEXES.TABLE_NAME, '^(SYS_IOT|MDOS|MDRS|MDRT|MDOT|MDXT)_.*$')
-ORDER BY 
+ORDER BY
   TABLE_SCHEM,
   TABLE_NAME,
   INDEX_NAME,
-  NON_UNIQUE, 
-  TYPE,  
+  NON_UNIQUE,
+  TYPE,
   ORDINAL_POSITION
